[ekiga] Made the sources use signals2



commit 12641b735a9886a080949465d4da6d4569822ed2
Author: Julien Puydt <jpuydt free fr>
Date:   Sat Sep 14 17:49:31 2013 +0200

    Made the sources use signals2

 lib/engine/account/account-core.h                  |   12 ++++----
 lib/engine/account/bank-impl.h                     |    2 +-
 lib/engine/account/bank.h                          |    6 ++--
 lib/engine/addressbook/book.h                      |    6 ++--
 lib/engine/addressbook/contact-core.h              |   14 ++++----
 lib/engine/addressbook/source.h                    |   12 ++++----
 lib/engine/audioinput/audioinput-core.h            |   12 ++++----
 lib/engine/audioinput/audioinput-manager.h         |    8 ++--
 lib/engine/audiooutput/audiooutput-core.h          |   12 ++++----
 lib/engine/audiooutput/audiooutput-manager.h       |    8 ++--
 lib/engine/chat/chat-core.h                        |    4 +-
 lib/engine/chat/chat.h                             |    8 ++--
 lib/engine/chat/dialect-impl.h                     |    2 +-
 lib/engine/chat/dialect.h                          |    4 +-
 lib/engine/components/call-history/history-book.h  |    4 +-
 .../components/call-history/history-contact.h      |    2 +-
 lib/engine/components/local-roster/local-cluster.h |    2 +-
 .../components/local-roster/local-presentity.h     |    2 +-
 lib/engine/components/opal/opal-account.h          |    2 +-
 lib/engine/components/opal/opal-call.h             |    2 +-
 lib/engine/components/opal/opal-gmconf-bridge.cpp  |    2 +-
 lib/engine/components/opal/sip-endpoint.h          |    4 +-
 lib/engine/framework/chain-of-responsibility.h     |    7 ++--
 lib/engine/framework/form-request-simple.h         |    2 +-
 lib/engine/framework/gmconf-bridge.h               |    4 +-
 lib/engine/framework/live-object.h                 |    4 +-
 lib/engine/framework/menu-builder.h                |    2 +-
 lib/engine/framework/personal-details.h            |    4 +-
 lib/engine/framework/reflister.h                   |   12 ++++----
 lib/engine/framework/runtime.h                     |    2 +-
 lib/engine/framework/scoped-connections.h          |   10 +++---
 lib/engine/framework/services.h                    |    4 +-
 lib/engine/gui/gtk-core/codecsbox.cpp              |    2 +
 lib/engine/gui/gtk-frontend/accounts-window.cpp    |    2 +-
 lib/engine/gui/gtk-frontend/addressbook-window.cpp |    2 +-
 lib/engine/gui/gtk-frontend/assistant-window.cpp   |    2 +-
 .../gui/gtk-frontend/call-history-view-gtk.cpp     |    2 +-
 lib/engine/gui/gtk-frontend/call-window.cpp        |    2 +-
 lib/engine/gui/gtk-frontend/chat-area.cpp          |    2 +-
 lib/engine/gui/gtk-frontend/heap-view.cpp          |    2 +-
 lib/engine/gui/gtk-frontend/main_window.cpp        |    2 +-
 lib/engine/gui/gtk-frontend/preferences-window.cpp |    2 +-
 lib/engine/gui/gtk-frontend/presentity-view.cpp    |    4 +-
 lib/engine/gui/gtk-frontend/roster-view-gtk.cpp    |    2 +-
 lib/engine/gui/gtk-frontend/statusicon.cpp         |    2 +-
 lib/engine/gui/gtk-frontend/statusicon.h           |    2 +-
 lib/engine/gui/gtk-frontend/statusmenu.cpp         |    2 +-
 lib/engine/hal/hal-core.h                          |   20 ++++++------
 lib/engine/hal/hal-manager.h                       |   16 +++++-----
 lib/engine/notification/notification-core.h        |    4 +-
 lib/engine/presence/cluster.h                      |   12 ++++----
 lib/engine/presence/heap.h                         |    6 ++--
 lib/engine/presence/presence-core.h                |   22 +++++++-------
 lib/engine/presence/uri-presentity.h               |    2 +-
 lib/engine/protocol/call-core.h                    |   32 ++++++++++----------
 lib/engine/protocol/call-manager.h                 |    6 ++--
 lib/engine/protocol/call.h                         |   28 ++++++++--------
 lib/engine/videoinput/videoinput-core.h            |   14 ++++----
 lib/engine/videoinput/videoinput-manager.h         |    8 ++--
 lib/engine/videooutput/videooutput-core.h          |   14 ++++----
 lib/engine/videooutput/videooutput-manager.h       |   12 ++++----
 plugins/avahi/avahi-cluster.h                      |    2 +-
 plugins/avahi/avahi-heap.h                         |    2 +-
 plugins/ldap/ldap-book.h                           |    2 +-
 plugins/libnotify/libnotify-main.cpp               |    8 ++--
 plugins/loudmouth/loudmouth-account.h              |    2 +-
 plugins/loudmouth/loudmouth-heap-roster.h          |    2 +-
 plugins/loudmouth/loudmouth-helpers.h              |    2 +-
 plugins/loudmouth/loudmouth-presentity.h           |    2 +-
 plugins/resource-list/rl-heap.cpp                  |   12 ++++----
 plugins/resource-list/rl-heap.h                    |    4 +-
 plugins/resource-list/rl-list.cpp                  |   24 +++++++-------
 plugins/resource-list/rl-list.h                    |    6 ++--
 plugins/resource-list/rl-presentity.h              |    2 +-
 74 files changed, 240 insertions(+), 239 deletions(-)
---
diff --git a/lib/engine/account/account-core.h b/lib/engine/account/account-core.h
index f95782d..1b7454f 100644
--- a/lib/engine/account/account-core.h
+++ b/lib/engine/account/account-core.h
@@ -106,26 +106,26 @@ namespace Ekiga
 
     /** This signal is emitted when a bank has been added to the core
      */
-    boost::signal1<void, BankPtr> bank_added;
+    boost::signals2::signal<void(BankPtr)> bank_added;
 
     /** This signal is emitted when a bank has been removed from the core
      */
-    boost::signal1<void, BankPtr> bank_removed;
+    boost::signals2::signal<void(BankPtr)> bank_removed;
 
     /** This signal is emitted when a account has been added to one of
      * the banks
      */
-    boost::signal2<void, BankPtr, AccountPtr> account_added;
+    boost::signals2::signal<void(BankPtr, AccountPtr)> account_added;
 
     /** This signal is emitted when a account has been removed from one of
      * the banks
      */
-    boost::signal2<void, BankPtr, AccountPtr> account_removed;
+    boost::signals2::signal<void(BankPtr, AccountPtr)> account_removed;
 
     /** This signal is emitted when a account has been updated in one of
      * the banks
      */
-    boost::signal2<void, BankPtr, AccountPtr> account_updated;
+    boost::signals2::signal<void(BankPtr, AccountPtr)> account_updated;
 
   private:
 
@@ -147,7 +147,7 @@ namespace Ekiga
     /** This signal is emitted when the AccountCore Service has been
      * updated.
      */
-    boost::signal0<void> updated;
+    boost::signals2::signal<void(void)> updated;
 
 
     /** This chain allows the AccountCore to present forms to the user
diff --git a/lib/engine/account/bank-impl.h b/lib/engine/account/bank-impl.h
index b0a8775..52c917a 100644
--- a/lib/engine/account/bank-impl.h
+++ b/lib/engine/account/bank-impl.h
@@ -74,7 +74,7 @@ namespace Ekiga
   template<class AccountType = Account>
   class BankImpl:
     public Bank,
-    public boost::signals::trackable,
+    public boost::signals2::trackable,
     protected RefLister<AccountType>
   {
 
diff --git a/lib/engine/account/bank.h b/lib/engine/account/bank.h
index de55493..a825023 100644
--- a/lib/engine/account/bank.h
+++ b/lib/engine/account/bank.h
@@ -74,15 +74,15 @@ namespace Ekiga
 
     /** This signal is emitted when a account has been added.
      */
-    boost::signal1<void, AccountPtr> account_added;
+    boost::signals2::signal<void(AccountPtr)> account_added;
 
     /** This signal is emitted when a account has been removed.
      */
-    boost::signal1<void, AccountPtr> account_removed;
+    boost::signals2::signal<void(AccountPtr)> account_removed;
 
     /** This signal is emitted when a account has been updated.
      */
-    boost::signal1<void, AccountPtr> account_updated;
+    boost::signals2::signal<void(AccountPtr)> account_updated;
 
     /** This chain allows the BankImpl to present forms to the user
      */
diff --git a/lib/engine/addressbook/book.h b/lib/engine/addressbook/book.h
index 3712e2c..a0dc893 100644
--- a/lib/engine/addressbook/book.h
+++ b/lib/engine/addressbook/book.h
@@ -92,17 +92,17 @@ namespace Ekiga {
 
     /** This signal is emitted when a Contact has been added to the Book.
      */
-    boost::signal1<void, ContactPtr > contact_added;
+    boost::signals2::signal<void(ContactPtr)> contact_added;
 
 
     /** This signal is emitted when a Contact has been removed from the Book.
      */
-    boost::signal1<void, ContactPtr > contact_removed;
+    boost::signals2::signal<void(ContactPtr)> contact_removed;
 
 
     /** This signal is emitted when a Contact has been updated in the Book.
      */
-    boost::signal1<void, ContactPtr > contact_updated;
+    boost::signals2::signal<void(ContactPtr)> contact_updated;
   };
 
   typedef boost::shared_ptr<Book> BookPtr;
diff --git a/lib/engine/addressbook/contact-core.h b/lib/engine/addressbook/contact-core.h
index 098bb03..6bbc8c4 100644
--- a/lib/engine/addressbook/contact-core.h
+++ b/lib/engine/addressbook/contact-core.h
@@ -115,37 +115,37 @@ namespace Ekiga
     /** This signal is emitted when a Ekiga::Source has been
      * added to the ContactCore Service.
      */
-    boost::signal1<void, SourcePtr > source_added;
+    boost::signals2::signal<void(SourcePtr)> source_added;
 
     /** This signal is emitted when a book has been added to one of
      * the sources
      */
-    boost::signal2<void, SourcePtr, BookPtr > book_added;
+    boost::signals2::signal<void(SourcePtr, BookPtr )> book_added;
 
     /** This signal is emitted when a book has been removed from one of
      * the sources
      */
-    boost::signal2<void, SourcePtr, BookPtr > book_removed;
+    boost::signals2::signal<void(SourcePtr, BookPtr )> book_removed;
 
     /** This signal is emitted when a book has been updated in one of
      * the sources
      */
-    boost::signal2<void, SourcePtr, BookPtr > book_updated;
+    boost::signals2::signal<void(SourcePtr, BookPtr )> book_updated;
 
     /** This signal is emitted when a contact has been added to one of
      * the book of one of the sources
      */
-    boost::signal3<void, SourcePtr, BookPtr, ContactPtr > contact_added;
+    boost::signals2::signal<void(SourcePtr, BookPtr, ContactPtr )> contact_added;
 
     /** This signal is emitted when a contact has been removed from one of
      * the book of one of the sources
      */
-    boost::signal3<void, SourcePtr, BookPtr, ContactPtr > contact_removed;
+    boost::signals2::signal<void(SourcePtr, BookPtr, ContactPtr )> contact_removed;
 
     /** This signal is emitted when a contact has been updated in one of
      * the book of one of the sources
      */
-    boost::signal3<void, SourcePtr, BookPtr, ContactPtr > contact_updated;
+    boost::signals2::signal<void(SourcePtr, BookPtr, ContactPtr )> contact_updated;
 
   private:
 
diff --git a/lib/engine/addressbook/source.h b/lib/engine/addressbook/source.h
index 35accd6..e26aa09 100644
--- a/lib/engine/addressbook/source.h
+++ b/lib/engine/addressbook/source.h
@@ -63,32 +63,32 @@ namespace Ekiga {
 
     /** This signal is emitted when a Book has been added to the Source.
      */
-    boost::signal1<void, BookPtr > book_added;
+    boost::signals2::signal<void(BookPtr)> book_added;
     
     
     /** This signal is emitted when a Book has been updated in the Source.
      */
-    boost::signal1<void, BookPtr > book_updated;
+    boost::signals2::signal<void(BookPtr)> book_updated;
     
     
     /** This signal is emitted when a Book has been removed in the Source.
      */
-    boost::signal1<void, BookPtr > book_removed;
+    boost::signals2::signal<void(BookPtr)> book_removed;
 
     /** This signal is emitted when a Contact has been added to a book in
      *  this source.
      */
-    boost::signal2<void, BookPtr, ContactPtr > contact_added;
+    boost::signals2::signal<void(BookPtr, ContactPtr )> contact_added;
 
     /** This signal is emitted when a Contact has been removed from a book in
      *  this source.
      */
-    boost::signal2<void, BookPtr, ContactPtr > contact_removed;
+    boost::signals2::signal<void(BookPtr, ContactPtr )> contact_removed;
 
     /** This signal is emitted when a Contact has been updated in a book in
      *  this source
      */
-    boost::signal2<void, BookPtr, ContactPtr > contact_updated;
+    boost::signals2::signal<void(BookPtr, ContactPtr )> contact_updated;
   };
 
   typedef boost::shared_ptr<Source> SourcePtr;
diff --git a/lib/engine/audioinput/audioinput-core.h b/lib/engine/audioinput/audioinput-core.h
index f943047..60901d3 100644
--- a/lib/engine/audioinput/audioinput-core.h
+++ b/lib/engine/audioinput/audioinput-core.h
@@ -135,7 +135,7 @@ namespace Ekiga
       /** This signal is emitted when a Ekiga::AudioInputManager has been
        * added to the AudioInputCore Service.
        */
-      boost::signal1<void, AudioInputManager &> manager_added;
+      boost::signals2::signal<void(AudioInputManager &)> manager_added;
 
 
       /*** AudioInput Device Management ***/
@@ -253,23 +253,23 @@ namespace Ekiga
 
       /** See audioinput-manager.h for the API
        */
-      boost::signal3<void, AudioInputManager &, AudioInputDevice &, AudioInputSettings&> device_opened;
-      boost::signal2<void, AudioInputManager &, AudioInputDevice &> device_closed;
-      boost::signal3<void, AudioInputManager &, AudioInputDevice &, AudioInputErrorCodes> device_error;
+      boost::signals2::signal<void(AudioInputManager &, AudioInputDevice &, AudioInputSettings&)> 
device_opened;
+      boost::signals2::signal<void(AudioInputManager &, AudioInputDevice &)> device_closed;
+      boost::signals2::signal<void(AudioInputManager &, AudioInputDevice &, AudioInputErrorCodes)> 
device_error;
 
       /** This signal is emitted when an audio device input has been added to the system.
        * This signal will be emitted if add_device was called with a device name and
        * a manager claimed support for this device.
        * @param device the audio input device that was added.
        */
-      boost::signal2<void, AudioInputDevice, bool> device_added;
+      boost::signals2::signal<void(AudioInputDevice, bool)> device_added;
 
       /** This signal is emitted when an audio input device has been removed from the system.
        * This signal will be emitted if remove_device was called with a device name and
        * a manager claimed support for this device.
        * @param device the audio input device that was removed.
        */
-      boost::signal2<void, AudioInputDevice, bool> device_removed;
+      boost::signals2::signal<void(AudioInputDevice, bool)> device_removed;
 
   private:
       void on_set_device (const AudioInputDevice & device);
diff --git a/lib/engine/audioinput/audioinput-manager.h b/lib/engine/audioinput/audioinput-manager.h
index 0ae9296..28e9f79 100644
--- a/lib/engine/audioinput/audioinput-manager.h
+++ b/lib/engine/audioinput/audioinput-manager.h
@@ -39,7 +39,7 @@
 #define __AUDIOINPUT_MANAGER_H__
 
 #include <vector>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include "audioinput-info.h"
@@ -148,18 +148,18 @@ namespace Ekiga
        * @param device the audio input device that was opened.
        * @param config the current audio input device configuration (current volume, etc.).
        */
-      boost::signal2<void, AudioInputDevice, AudioInputSettings> device_opened;
+      boost::signals2::signal<void(AudioInputDevice, AudioInputSettings)> device_opened;
 
       /** This signal is emitted when an audio input device is closed.
        * @param device the audio input device that was closed.
        */
-      boost::signal1<void, AudioInputDevice> device_closed;
+      boost::signals2::signal<void(AudioInputDevice)> device_closed;
 
       /** This signal is emitted when an error occurs when opening a audio input device.
        * @param device the audio input device that caused the error.
        * @param error_code the audio input device error code.
        */
-      boost::signal2<void, AudioInputDevice, AudioInputErrorCodes> device_error;
+      boost::signals2::signal<void(AudioInputDevice, AudioInputErrorCodes)> device_error;
 
 
   protected:  
diff --git a/lib/engine/audiooutput/audiooutput-core.h b/lib/engine/audiooutput/audiooutput-core.h
index d447880..5b6a74e 100644
--- a/lib/engine/audiooutput/audiooutput-core.h
+++ b/lib/engine/audiooutput/audiooutput-core.h
@@ -127,7 +127,7 @@ namespace Ekiga
       /** This signal is emitted when a Ekiga::AudioOutputManager has been
        * added to the AudioOutputCore Service.
        */
-      boost::signal1<void, AudioOutputManager &> manager_added;
+      boost::signals2::signal<void(AudioOutputManager &)> manager_added;
 
 
       /** Get a list of all devices supported by all managers registered to the core.
@@ -298,23 +298,23 @@ namespace Ekiga
 
       /** See audiooutput-manager.h for the API
        */
-      boost::signal4<void, AudioOutputManager &, AudioOutputPS, AudioOutputDevice&, AudioOutputSettings&> 
device_opened;
-      boost::signal3<void, AudioOutputManager &, AudioOutputPS, AudioOutputDevice&> device_closed;
-      boost::signal4<void, AudioOutputManager &, AudioOutputPS, AudioOutputDevice&, AudioOutputErrorCodes> 
device_error;
+      boost::signals2::signal<void(AudioOutputManager &, AudioOutputPS, AudioOutputDevice&, 
AudioOutputSettings&)> device_opened;
+      boost::signals2::signal<void(AudioOutputManager &, AudioOutputPS, AudioOutputDevice&)> device_closed;
+      boost::signals2::signal<void(AudioOutputManager &, AudioOutputPS, AudioOutputDevice&, 
AudioOutputErrorCodes)> device_error;
 
       /** This signal is emitted when an audio output device has been added to the system.
        * This signal will be emitted if add_device was called with a device name and
        * a manager claimed support for this device.
        * @param device the audio output device that was added.
        */
-      boost::signal2<void, AudioOutputDevice, bool> device_added;
+      boost::signals2::signal<void(AudioOutputDevice, bool)> device_added;
 
       /** This signal is emitted when an audio output device has been removed from the system.
        * This signal will be emitted if remove_device was called with a device name and
        * a manager claimed support for this device.
        * @param device the audio output device that was removed.
        */
-      boost::signal2<void, AudioOutputDevice, bool> device_removed;
+      boost::signals2::signal<void(AudioOutputDevice, bool)> device_removed;
 
   private:
       void on_set_device (const AudioOutputDevice & device);
diff --git a/lib/engine/audiooutput/audiooutput-manager.h b/lib/engine/audiooutput/audiooutput-manager.h
index e613e00..78cc20c 100644
--- a/lib/engine/audiooutput/audiooutput-manager.h
+++ b/lib/engine/audiooutput/audiooutput-manager.h
@@ -39,7 +39,7 @@
 #define __AUDIOOUTPUT_MANAGER_H__
 
 #include <vector>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include "audiooutput-info.h"
@@ -152,20 +152,20 @@ namespace Ekiga
        * @param device the audio output device that was opened.
        * @param config the current audio output device configuration (current volume, etc.).
        */
-      boost::signal3<void, AudioOutputPS, AudioOutputDevice, AudioOutputSettings> device_opened;
+      boost::signals2::signal<void(AudioOutputPS, AudioOutputDevice, AudioOutputSettings)> device_opened;
 
       /** This signal is emitted when an audio output device is closed.
        * @param prim whether the primary or secondary audio output device was closed.
        * @param device the audio output device that was closed.
        */
-      boost::signal2<void, AudioOutputPS, AudioOutputDevice> device_closed;
+      boost::signals2::signal<void(AudioOutputPS, AudioOutputDevice)> device_closed;
 
       /** This signal is emitted when an error occurs when opening an audio output device.
        * @param prim whether the primary or secondary audio output device caused the error.
        * @param device the audio output device that caused the error.
        * @param error_code the audio output device error code.
        */
-      boost::signal3<void, AudioOutputPS, AudioOutputDevice, AudioOutputErrorCodes> device_error;
+      boost::signals2::signal<void(AudioOutputPS, AudioOutputDevice, AudioOutputErrorCodes)> device_error;
 
   protected:  
       typedef struct ManagerState {
diff --git a/lib/engine/chat/chat-core.h b/lib/engine/chat/chat-core.h
index 9a7d7e1..444663c 100644
--- a/lib/engine/chat/chat-core.h
+++ b/lib/engine/chat/chat-core.h
@@ -100,7 +100,7 @@ namespace Ekiga
     /** This signal is emitted when an Ekiga::Dialect has been added to
      * the ChatCore service.
      */
-    boost::signal1<void, DialectPtr > dialect_added;
+    boost::signals2::signal<void(DialectPtr)> dialect_added;
 
   private:
 
@@ -116,7 +116,7 @@ namespace Ekiga
 
     /** This signal is emitted when the ChatCore service has been updated.
      */
-    boost::signal0<void> updated;
+    boost::signals2::signal<void(void)> updated;
 
     /** This chain allows the ChatCore to present forms to the user
      */
diff --git a/lib/engine/chat/chat.h b/lib/engine/chat/chat.h
index 08f568f..bcaf85c 100644
--- a/lib/engine/chat/chat.h
+++ b/lib/engine/chat/chat.h
@@ -37,7 +37,7 @@
 #define __CHAT_H__
 
 #include <string>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include <boost/smart_ptr.hpp>
@@ -113,15 +113,15 @@ namespace Ekiga
 
     /** This signal is emitted when the Chat has been updated.
      */
-    boost::signal0<void> updated;
+    boost::signals2::signal<void(void)> updated;
 
     /** This signal is emitted when the user requested to see this Chat
      */
-    boost::signal0<void> user_requested;
+    boost::signals2::signal<void(void)> user_requested;
 
     /** This signal is emitted when the Chat has been removed.
      */
-    boost::signal0<void> removed;
+    boost::signals2::signal<void(void)> removed;
 
     /** Feed possible actions on this Chat to the given MenuBuilder
      * @param A MenuBuilder object to populate.
diff --git a/lib/engine/chat/dialect-impl.h b/lib/engine/chat/dialect-impl.h
index 299aec3..1006c66 100644
--- a/lib/engine/chat/dialect-impl.h
+++ b/lib/engine/chat/dialect-impl.h
@@ -48,7 +48,7 @@ namespace Ekiga
           typename MultipleChatType = MultipleChat>
   class DialectImpl:
     public Dialect,
-    public boost::signals::trackable
+    public boost::signals2::trackable
   {
   public:
 
diff --git a/lib/engine/chat/dialect.h b/lib/engine/chat/dialect.h
index c6d8986..0af7832 100644
--- a/lib/engine/chat/dialect.h
+++ b/lib/engine/chat/dialect.h
@@ -72,12 +72,12 @@ namespace Ekiga
     /** This signal is emitted when an Ekiga::SimpleChat has been added to
      * the dialect.
      */
-    boost::signal1<void, SimpleChatPtr> simple_chat_added;
+    boost::signals2::signal<void(SimpleChatPtr)> simple_chat_added;
 
     /** This signal is emitted when an Ekiga::MultipleChat has been added to
      * the dialect.
      */
-    boost::signal1<void, MultipleChatPtr> multiple_chat_added;
+    boost::signals2::signal<void(MultipleChatPtr)> multiple_chat_added;
 
     /** This chain allows the Dialect to present forms to the user.
      */
diff --git a/lib/engine/components/call-history/history-book.h 
b/lib/engine/components/call-history/history-book.h
index 8acf3dc..c561ffb 100644
--- a/lib/engine/components/call-history/history-book.h
+++ b/lib/engine/components/call-history/history-book.h
@@ -53,7 +53,7 @@ namespace History
 
   class Book:
     public Ekiga::Book,
-    public boost::signals::trackable
+    public boost::signals2::trackable
   {
   public:
 
@@ -86,7 +86,7 @@ namespace History
 
     void clear ();
 
-    boost::signal0<void> cleared;
+    boost::signals2::signal<void(void)> cleared;
 
   private:
 
diff --git a/lib/engine/components/call-history/history-contact.h 
b/lib/engine/components/call-history/history-contact.h
index 3836659..e436aa8 100644
--- a/lib/engine/components/call-history/history-contact.h
+++ b/lib/engine/components/call-history/history-contact.h
@@ -61,7 +61,7 @@ namespace History
 
   class Contact:
     public Ekiga::Contact,
-    public boost::signals::trackable
+    public boost::signals2::trackable
   {
   public:
 
diff --git a/lib/engine/components/local-roster/local-cluster.h 
b/lib/engine/components/local-roster/local-cluster.h
index 5d9f01f..18bf2bd 100644
--- a/lib/engine/components/local-roster/local-cluster.h
+++ b/lib/engine/components/local-roster/local-cluster.h
@@ -51,7 +51,7 @@ namespace Local
   class Cluster :
     public Ekiga::ClusterImpl<Heap>,
     public Ekiga::Trigger,
-    public boost::signals::trackable
+    public boost::signals2::trackable
   {
   public:
 
diff --git a/lib/engine/components/local-roster/local-presentity.h 
b/lib/engine/components/local-roster/local-presentity.h
index f83ff09..095df80 100644
--- a/lib/engine/components/local-roster/local-presentity.h
+++ b/lib/engine/components/local-roster/local-presentity.h
@@ -166,7 +166,7 @@ namespace Local
      * This signal makes the Local::Heap know that the XML tree changed
      * and hence should be saved
      */
-    boost::signal0<void> trigger_saving;
+    boost::signals2::signal<void(void)> trigger_saving;
 
 
   private:
diff --git a/lib/engine/components/opal/opal-account.h b/lib/engine/components/opal/opal-account.h
index d38cf2e..9e01dc6 100644
--- a/lib/engine/components/opal/opal-account.h
+++ b/lib/engine/components/opal/opal-account.h
@@ -164,7 +164,7 @@ public:
 
     const std::string as_string () const;
 
-    boost::signal0<void> trigger_saving;
+    boost::signals2::signal<void(void)> trigger_saving;
 
     /*
      * This is because an opal account is an Ekiga::PresencePublisher
diff --git a/lib/engine/components/opal/opal-call.h b/lib/engine/components/opal/opal-call.h
index cdbc672..6968419 100644
--- a/lib/engine/components/opal/opal-call.h
+++ b/lib/engine/components/opal/opal-call.h
@@ -57,7 +57,7 @@ namespace Opal {
   class Call
     : public OpalCall,
       public Ekiga::Call,
-      public boost::signals::trackable
+      public boost::signals2::trackable
   {
 
 public:
diff --git a/lib/engine/components/opal/opal-gmconf-bridge.cpp 
b/lib/engine/components/opal/opal-gmconf-bridge.cpp
index 9c09f7a..f855b22 100644
--- a/lib/engine/components/opal/opal-gmconf-bridge.cpp
+++ b/lib/engine/components/opal/opal-gmconf-bridge.cpp
@@ -35,7 +35,7 @@
  */
 
 #include <iostream>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include "config.h"
diff --git a/lib/engine/components/opal/sip-endpoint.h b/lib/engine/components/opal/sip-endpoint.h
index 2c634a5..d4af937 100644
--- a/lib/engine/components/opal/sip-endpoint.h
+++ b/lib/engine/components/opal/sip-endpoint.h
@@ -115,11 +115,11 @@ namespace Opal {
 
       // a registration event occurred
       // the parameters are the aor, the state and the message
-      boost::signal3<void, std::string, Opal::Account::RegistrationState, std::string> registration_event;
+      boost::signals2::signal<void(std::string, Opal::Account::RegistrationState, std::string)> 
registration_event;
 
       // a message waiting information was received
       // the parameters are the aor and the info
-      boost::signal2<void, std::string, std::string> mwi_event;
+      boost::signals2::signal<void(std::string, std::string)> mwi_event;
 
       /* AccountSubscriber */
       bool subscribe (const Opal::Account & account, const PSafePtr<OpalPresentity> & presentity);
diff --git a/lib/engine/framework/chain-of-responsibility.h b/lib/engine/framework/chain-of-responsibility.h
index 399992b..46c95fe 100644
--- a/lib/engine/framework/chain-of-responsibility.h
+++ b/lib/engine/framework/chain-of-responsibility.h
@@ -36,7 +36,7 @@
 #ifndef __CHAIN_OF_RESPONSIBILITY_H__
 #define __CHAIN_OF_RESPONSIBILITY_H__
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 /* This code uses boost signals to implement the "chain of responsibility"
@@ -117,9 +117,8 @@ namespace Ekiga
 
   template<typename T_request>
   struct ChainOfResponsibility:
-    public boost::signal1<bool,
-                        T_request,
-                        responsibility_accumulator>
+    public boost::signals2::signal<bool(T_request),
+                                  responsibility_accumulator>
   {
   };
 };
diff --git a/lib/engine/framework/form-request-simple.h b/lib/engine/framework/form-request-simple.h
index 85211ab..74b84ae 100644
--- a/lib/engine/framework/form-request-simple.h
+++ b/lib/engine/framework/form-request-simple.h
@@ -36,7 +36,7 @@
 #ifndef __FORM_REQUEST_SIMPLE_H__
 #define __FORM_REQUEST_SIMPLE_H__
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include "form-builder.h"
diff --git a/lib/engine/framework/gmconf-bridge.h b/lib/engine/framework/gmconf-bridge.h
index 94cbdbc..67293e1 100644
--- a/lib/engine/framework/gmconf-bridge.h
+++ b/lib/engine/framework/gmconf-bridge.h
@@ -38,7 +38,7 @@
 #define __GMCONF_BRIDGE_H__
 
 #include <vector>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include "gmconf.h"
@@ -95,7 +95,7 @@ namespace Ekiga
        * @param key is the GmConf key whose value changed
        * @param entry is the new GmConf entry
        */
-      boost::signal2<void, std::string /*key*/, GmConfEntry * /*entry*/> property_changed;
+      boost::signals2::signal<void(std::string /*key*/, GmConfEntry * /*entry*/)> property_changed;
 
   private:
       std::list<gpointer> notifiers;
diff --git a/lib/engine/framework/live-object.h b/lib/engine/framework/live-object.h
index c672ad3..dfd33a8 100644
--- a/lib/engine/framework/live-object.h
+++ b/lib/engine/framework/live-object.h
@@ -62,12 +62,12 @@ namespace Ekiga
 
     /** This signal is emitted when the object has been updated.
      */
-    boost::signal0<void> updated;
+    boost::signals2::signal<void(void)> updated;
 
 
     /** This signal is emitted when the object has been removed.
      */
-    boost::signal0<void> removed;
+    boost::signals2::signal<void(void)> removed;
 
     /** This chain allows the object to present forms to the user
      */
diff --git a/lib/engine/framework/menu-builder.h b/lib/engine/framework/menu-builder.h
index c67d712..2d2717d 100644
--- a/lib/engine/framework/menu-builder.h
+++ b/lib/engine/framework/menu-builder.h
@@ -37,7 +37,7 @@
 #define __MENU_BUILDER_H__
 
 #include <string>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 
diff --git a/lib/engine/framework/personal-details.h b/lib/engine/framework/personal-details.h
index 04ddf97..d620ea9 100644
--- a/lib/engine/framework/personal-details.h
+++ b/lib/engine/framework/personal-details.h
@@ -37,7 +37,7 @@
 #define __PERSONAL_DETAILS_H__
 
 #include <string>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include "services.h"
@@ -66,7 +66,7 @@ namespace Ekiga
     virtual void set_presence_info (const std::string presence,
                                     const std::string status) = 0;
 
-    boost::signal0<void> updated;
+    boost::signals2::signal<void(void)> updated;
   };
 };
 
diff --git a/lib/engine/framework/reflister.h b/lib/engine/framework/reflister.h
index c4ab963..2a6bb40 100644
--- a/lib/engine/framework/reflister.h
+++ b/lib/engine/framework/reflister.h
@@ -37,7 +37,7 @@
 #ifndef __REFLISTER_H__
 #define __REFLISTER_H__
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 #include <list>
 
@@ -65,7 +65,7 @@ namespace Ekiga
     void add_object (boost::shared_ptr<ObjectType> obj);
 
     void add_connection (boost::shared_ptr<ObjectType> obj,
-                        boost::signals::connection connection);
+                        boost::signals2::connection connection);
 
     void remove_object (boost::shared_ptr<ObjectType> obj);
 
@@ -77,9 +77,9 @@ namespace Ekiga
     const_iterator begin () const;
     const_iterator end () const;
 
-    boost::signal1<void, boost::shared_ptr<ObjectType> > object_added;
-    boost::signal1<void, boost::shared_ptr<ObjectType> > object_removed;
-    boost::signal1<void, boost::shared_ptr<ObjectType> > object_updated;
+    boost::signals2::signal<void(boost::shared_ptr<ObjectType>)> object_added;
+    boost::signals2::signal<void(boost::shared_ptr<ObjectType>)> object_removed;
+    boost::signals2::signal<void(boost::shared_ptr<ObjectType>)> object_updated;
 
   private:
     container_type objects;
@@ -117,7 +117,7 @@ Ekiga::RefLister<ObjectType>::add_object (boost::shared_ptr<ObjectType> obj)
 template<typename ObjectType>
 void
 Ekiga::RefLister<ObjectType>::add_connection (boost::shared_ptr<ObjectType> obj,
-                                             boost::signals::connection connection)
+                                             boost::signals2::connection connection)
 {
   typename container_type::iterator iter = objects.find (obj);
   if (iter == objects.end ())
diff --git a/lib/engine/framework/runtime.h b/lib/engine/framework/runtime.h
index 1bb29a8..8fa2657 100644
--- a/lib/engine/framework/runtime.h
+++ b/lib/engine/framework/runtime.h
@@ -34,7 +34,7 @@
  *
  */
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #ifndef __RUNTIME_H__
diff --git a/lib/engine/framework/services.h b/lib/engine/framework/services.h
index ecc4a71..bdcc5db 100644
--- a/lib/engine/framework/services.h
+++ b/lib/engine/framework/services.h
@@ -45,7 +45,7 @@
 
 #include <list>
 #include <string>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 namespace Ekiga
@@ -103,7 +103,7 @@ namespace Ekiga
 
     void dump (std::ostream &stream) const;
 
-    boost::signal1<void, ServicePtr> service_added;
+    boost::signals2::signal<void(ServicePtr)> service_added;
 
   private:
 
diff --git a/lib/engine/gui/gtk-core/codecsbox.cpp b/lib/engine/gui/gtk-core/codecsbox.cpp
index 4784106..a11cabc 100644
--- a/lib/engine/gui/gtk-core/codecsbox.cpp
+++ b/lib/engine/gui/gtk-core/codecsbox.cpp
@@ -37,6 +37,8 @@
 
 #include "codecsbox.h"
 
+#include <sstream>
+
 #include <glib/gi18n.h>
 
 #include "gmconf.h"
diff --git a/lib/engine/gui/gtk-frontend/accounts-window.cpp b/lib/engine/gui/gtk-frontend/accounts-window.cpp
index 5035fa9..336de11 100644
--- a/lib/engine/gui/gtk-frontend/accounts-window.cpp
+++ b/lib/engine/gui/gtk-frontend/accounts-window.cpp
@@ -527,7 +527,7 @@ accounts_window_new (boost::shared_ptr<Ekiga::AccountCore> account_core,
 {
   AccountsWindow *self = NULL;
 
-  boost::signals::connection conn;
+  boost::signals2::connection conn;
 
   GtkWidget *vbox = NULL;
   GtkWidget *menu_bar = NULL;
diff --git a/lib/engine/gui/gtk-frontend/addressbook-window.cpp 
b/lib/engine/gui/gtk-frontend/addressbook-window.cpp
index 582c5b5..a60ec16 100644
--- a/lib/engine/gui/gtk-frontend/addressbook-window.cpp
+++ b/lib/engine/gui/gtk-frontend/addressbook-window.cpp
@@ -604,7 +604,7 @@ addressbook_window_new (boost::shared_ptr<Ekiga::ContactCore> core)
 {
   AddressBookWindow *self = NULL;
 
-  boost::signals::connection conn;
+  boost::signals2::connection conn;
 
   GtkWidget *menu_bar = NULL;
   GtkWidget *frame = NULL;
diff --git a/lib/engine/gui/gtk-frontend/assistant-window.cpp 
b/lib/engine/gui/gtk-frontend/assistant-window.cpp
index 9600d9a..da0d89d 100644
--- a/lib/engine/gui/gtk-frontend/assistant-window.cpp
+++ b/lib/engine/gui/gtk-frontend/assistant-window.cpp
@@ -1606,7 +1606,7 @@ assistant_window_new (Ekiga::ServiceCore& service_core)
   g_signal_connect (assistant, "key-press-event",
                     G_CALLBACK (assistant_window_key_press_cb), NULL);
 
-  boost::signals::connection conn;
+  boost::signals2::connection conn;
   assistant->priv->videoinput_core = service_core.get<Ekiga::VideoInputCore> ("videoinput-core");
   assistant->priv->audioinput_core = service_core.get<Ekiga::AudioInputCore> ("audioinput-core");
   assistant->priv->audiooutput_core = service_core.get<Ekiga::AudioOutputCore> ("audiooutput-core");
diff --git a/lib/engine/gui/gtk-frontend/call-history-view-gtk.cpp 
b/lib/engine/gui/gtk-frontend/call-history-view-gtk.cpp
index 2a08af8..5f28a48 100644
--- a/lib/engine/gui/gtk-frontend/call-history-view-gtk.cpp
+++ b/lib/engine/gui/gtk-frontend/call-history-view-gtk.cpp
@@ -54,7 +54,7 @@ struct _CallHistoryViewGtkPrivate
   boost::shared_ptr<History::Book> book;
   GtkListStore* store;
   GtkTreeView* tree;
-  boost::signals::scoped_connection connection;
+  boost::signals2::scoped_connection connection;
 };
 
 /* this is what we put in the view */
diff --git a/lib/engine/gui/gtk-frontend/call-window.cpp b/lib/engine/gui/gtk-frontend/call-window.cpp
index a3fa2d7..b070d7b 100644
--- a/lib/engine/gui/gtk-frontend/call-window.cpp
+++ b/lib/engine/gui/gtk-frontend/call-window.cpp
@@ -2198,7 +2198,7 @@ ekiga_call_window_transfer_dialog_run (EkigaCallWindow *cw,
 static void
 ekiga_call_window_connect_engine_signals (EkigaCallWindow *cw)
 {
-  boost::signals::connection conn;
+  boost::signals2::connection conn;
 
   g_return_if_fail (EKIGA_IS_CALL_WINDOW (cw));
 
diff --git a/lib/engine/gui/gtk-frontend/chat-area.cpp b/lib/engine/gui/gtk-frontend/chat-area.cpp
index d411a98..2cb5165 100644
--- a/lib/engine/gui/gtk-frontend/chat-area.cpp
+++ b/lib/engine/gui/gtk-frontend/chat-area.cpp
@@ -57,7 +57,7 @@ class ChatAreaHelper;
 struct _ChatAreaPrivate
 {
   boost::shared_ptr<Ekiga::Chat> chat;
-  boost::signals::scoped_connection connection;
+  boost::signals2::scoped_connection connection;
   boost::shared_ptr<ChatAreaHelper> helper;
   GmTextBufferEnhancer* enhancer;
 
diff --git a/lib/engine/gui/gtk-frontend/heap-view.cpp b/lib/engine/gui/gtk-frontend/heap-view.cpp
index 71e23d7..7112bbe 100644
--- a/lib/engine/gui/gtk-frontend/heap-view.cpp
+++ b/lib/engine/gui/gtk-frontend/heap-view.cpp
@@ -457,7 +457,7 @@ heap_view_set_heap (HeapView* self,
 
   if (heap) {
 
-    boost::signals::connection conn;
+    boost::signals2::connection conn;
 
     conn = heap->removed.connect (boost::bind (&on_heap_removed, self));
     self->priv->connections.add (conn);
diff --git a/lib/engine/gui/gtk-frontend/main_window.cpp b/lib/engine/gui/gtk-frontend/main_window.cpp
index 87b1003..163fa62 100644
--- a/lib/engine/gui/gtk-frontend/main_window.cpp
+++ b/lib/engine/gui/gtk-frontend/main_window.cpp
@@ -1526,7 +1526,7 @@ ekiga_main_window_class_init (EkigaMainWindowClass *klass)
 static void
 ekiga_main_window_connect_engine_signals (EkigaMainWindow *mw)
 {
-  boost::signals::connection conn;
+  boost::signals2::connection conn;
 
   g_return_if_fail (EKIGA_IS_MAIN_WINDOW (mw));
 
diff --git a/lib/engine/gui/gtk-frontend/preferences-window.cpp 
b/lib/engine/gui/gtk-frontend/preferences-window.cpp
index fa7beca..a40b51b 100644
--- a/lib/engine/gui/gtk-frontend/preferences-window.cpp
+++ b/lib/engine/gui/gtk-frontend/preferences-window.cpp
@@ -1255,7 +1255,7 @@ preferences_window_new (Ekiga::ServiceCore& core)
 
   gm_window_hide_on_delete (window);
 
-  boost::signals::connection conn;
+  boost::signals2::connection conn;
 
   conn = pw->videoinput_core->device_added.connect (boost::bind (&on_videoinput_device_added_cb, _1, _2, 
window));
   pw->connections.add (conn);
diff --git a/lib/engine/gui/gtk-frontend/presentity-view.cpp b/lib/engine/gui/gtk-frontend/presentity-view.cpp
index daab0c2..3c7cb7d 100644
--- a/lib/engine/gui/gtk-frontend/presentity-view.cpp
+++ b/lib/engine/gui/gtk-frontend/presentity-view.cpp
@@ -40,8 +40,8 @@
 struct _PresentityViewPrivate
 {
   Ekiga::Presentity* presentity;
-  boost::signals::connection updated_conn;
-  boost::signals::connection removed_conn;
+  boost::signals2::connection updated_conn;
+  boost::signals2::connection removed_conn;
 
   /* we contain those, so no need to unref them */
   GtkWidget* presence_image;
diff --git a/lib/engine/gui/gtk-frontend/roster-view-gtk.cpp b/lib/engine/gui/gtk-frontend/roster-view-gtk.cpp
index 740efdc..9e5ed2d 100644
--- a/lib/engine/gui/gtk-frontend/roster-view-gtk.cpp
+++ b/lib/engine/gui/gtk-frontend/roster-view-gtk.cpp
@@ -1554,7 +1554,7 @@ GtkWidget *
 roster_view_gtk_new (boost::shared_ptr<Ekiga::PresenceCore> core)
 {
   RosterViewGtk* self = NULL;
-  boost::signals::connection conn;
+  boost::signals2::connection conn;
 
   self = (RosterViewGtk *) g_object_new (ROSTER_VIEW_GTK_TYPE, NULL);
 
diff --git a/lib/engine/gui/gtk-frontend/statusicon.cpp b/lib/engine/gui/gtk-frontend/statusicon.cpp
index a07ead5..5f42661 100644
--- a/lib/engine/gui/gtk-frontend/statusicon.cpp
+++ b/lib/engine/gui/gtk-frontend/statusicon.cpp
@@ -530,7 +530,7 @@ status_icon_new (Ekiga::ServiceCore & core)
   if (!statusicon_should_run ())
     return self;
 
-  boost::signals::connection conn;
+  boost::signals2::connection conn;
 
   self = STATUSICON (g_object_new (STATUSICON_TYPE, NULL));
   self->priv = new StatusIconPrivate;
diff --git a/lib/engine/gui/gtk-frontend/statusicon.h b/lib/engine/gui/gtk-frontend/statusicon.h
index 19f81e1..ac78bab 100644
--- a/lib/engine/gui/gtk-frontend/statusicon.h
+++ b/lib/engine/gui/gtk-frontend/statusicon.h
@@ -42,7 +42,7 @@
 
 #include <gtk/gtk.h>
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 G_BEGIN_DECLS
diff --git a/lib/engine/gui/gtk-frontend/statusmenu.cpp b/lib/engine/gui/gtk-frontend/statusmenu.cpp
index f341a7f..7730630 100644
--- a/lib/engine/gui/gtk-frontend/statusmenu.cpp
+++ b/lib/engine/gui/gtk-frontend/statusmenu.cpp
@@ -49,7 +49,7 @@ struct _StatusMenuPrivate
   ~_StatusMenuPrivate ();
 
   boost::shared_ptr<Ekiga::PersonalDetails> personal_details;
-  boost::signals::connection connection;
+  boost::signals2::connection connection;
   std::list<gpointer> notifiers;
 
   GtkListStore *list_store; // List store storing the menu
diff --git a/lib/engine/hal/hal-core.h b/lib/engine/hal/hal-core.h
index 7e7bb68..545b5a1 100644
--- a/lib/engine/hal/hal-core.h
+++ b/lib/engine/hal/hal-core.h
@@ -40,7 +40,7 @@
 
 #include "services.h"
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include <set>
@@ -113,24 +113,24 @@ namespace Ekiga
       /** This signal is emitted when an Ekiga::HalManager has been
        * added to the HalCore Service.
        */
-       boost::signal1<void, HalManager &> manager_added;
+       boost::signals2::signal<void(HalManager &)> manager_added;
 
 
       /*** API to act on HAL events ***/
 
       /** See hal-manager.h for the API
        */
-      boost::signal4<void, const std::string &, const std::string &, unsigned, HalManager*> 
videoinput_device_added;
-      boost::signal4<void, const std::string &, const std::string &, unsigned, HalManager*> 
videoinput_device_removed;
+      boost::signals2::signal<void(const std::string &, const std::string &, unsigned, HalManager*)> 
videoinput_device_added;
+      boost::signals2::signal<void(const std::string &, const std::string &, unsigned, HalManager*)> 
videoinput_device_removed;
 
-      boost::signal3<void, const std::string &, const std::string &, HalManager*> audioinput_device_added;
-      boost::signal3<void, const std::string &, const std::string &, HalManager*> audioinput_device_removed;
+      boost::signals2::signal<void(const std::string &, const std::string &, HalManager*)> 
audioinput_device_added;
+      boost::signals2::signal<void(const std::string &, const std::string &, HalManager*)> 
audioinput_device_removed;
 
-      boost::signal3<void, const std::string &, const std::string &, HalManager*> audiooutput_device_added;
-      boost::signal3<void, const std::string &, const std::string &, HalManager*> audiooutput_device_removed;
+      boost::signals2::signal<void(const std::string &, const std::string &, HalManager*)> 
audiooutput_device_added;
+      boost::signals2::signal<void(const std::string &, const std::string &, HalManager*)> 
audiooutput_device_removed;
 
-      boost::signal3<void, const std::string &, const std::string &, HalManager*> network_interface_up;
-      boost::signal3<void, const std::string &, const std::string &, HalManager*> network_interface_down;
+      boost::signals2::signal<void(const std::string &, const std::string &, HalManager*)> 
network_interface_up;
+      boost::signals2::signal<void(const std::string &, const std::string &, HalManager*)> 
network_interface_down;
 
   private:
 
diff --git a/lib/engine/hal/hal-manager.h b/lib/engine/hal/hal-manager.h
index e0b2e75..7638214 100644
--- a/lib/engine/hal/hal-manager.h
+++ b/lib/engine/hal/hal-manager.h
@@ -75,50 +75,50 @@ namespace Ekiga
        * @param device the device name.
        * @param capabilities source-dependent device capabilites (e.g. V4L1 or V4L2 for video4linux).
        */
-      boost::signal3<void, std::string, std::string, unsigned> videoinput_device_added;
+      boost::signals2::signal<void(std::string, std::string, unsigned)> videoinput_device_added;
 
       /** This signal is emitted when a video input device is removed from the system.
        * @param source the video input framework (e.g. video4linux, etc.).
        * @param device the device name.
        * @param capabilities source-dependent device capabilites (e.g. V4L1 or V4L2 for video4linux).
        */
-      boost::signal3<void, std::string, std::string, unsigned> videoinput_device_removed;
+      boost::signals2::signal<void(std::string, std::string, unsigned)> videoinput_device_removed;
 
       /** This signal is emitted when an audio input device is added to the system.
        * @param source the audio input framework (e.g. alsa, oss, etc.).
        * @param device the device name.
        */
-      boost::signal2<void, std::string, std::string> audioinput_device_added;
+      boost::signals2::signal<void(std::string, std::string)> audioinput_device_added;
 
       /** This signal is emitted when an audio input device is removed from the system.
        * @param source the audio input framework (e.g. alsa, oss, etc.).
        * @param device the device name.
        */
-      boost::signal2<void, std::string, std::string> audioinput_device_removed;
+      boost::signals2::signal<void(std::string, std::string)> audioinput_device_removed;
 
       /** This signal is emitted when an audio output device is added to the system.
        * @param source the audio output framework (e.g. alsa, oss, etc.).
        * @param device the device name.
        */
-      boost::signal2<void, std::string, std::string> audiooutput_device_added;
+      boost::signals2::signal<void(std::string, std::string)> audiooutput_device_added;
 
       /** This signal is emitted when an audio output device is removed from the system.
        * @param source the audio output framework (e.g. alsa, oss, etc.).
        * @param device the device name.
        */
-      boost::signal2<void, std::string, std::string> audiooutput_device_removed;
+      boost::signals2::signal<void(std::string, std::string)> audiooutput_device_removed;
 
       /** This signal is emitted when a network device comes up.
        * @param interface_name the interface name (e.g. eth0, etc.).
        * @param ip4_address the IPv4 address (e.g. "192.168.0.1").
        */
-      boost::signal2<void, std::string, std::string> network_interface_up;
+      boost::signals2::signal<void(std::string, std::string)> network_interface_up;
 
       /** This signal is emitted when a network device goes down.
        * @param interface_name the interface name (e.g. eth0, etc.).
        * @param ip4_address the IPv4 address (e.g. "192.168.0.1").
        */
-      boost::signal2<void, std::string, std::string> network_interface_down;
+      boost::signals2::signal<void(std::string, std::string)> network_interface_down;
   };
 
 /**
diff --git a/lib/engine/notification/notification-core.h b/lib/engine/notification/notification-core.h
index caa8e00..323e0de 100644
--- a/lib/engine/notification/notification-core.h
+++ b/lib/engine/notification/notification-core.h
@@ -77,7 +77,7 @@ namespace Ekiga
     void action_trigger ()
     { if (action_callback) action_callback (); }
 
-    boost::signal0<void> removed;
+    boost::signals2::signal<void(void)> removed;
 
   private:
 
@@ -109,7 +109,7 @@ namespace Ekiga
     void push_notification (boost::shared_ptr<Notification> notification)
     { notification_added (notification); }
 
-    boost::signal1<void, boost::shared_ptr<Notification> > notification_added;
+    boost::signals2::signal<void(boost::shared_ptr<Notification>)> notification_added;
   };
 };
 
diff --git a/lib/engine/presence/cluster.h b/lib/engine/presence/cluster.h
index df44410..1677162 100644
--- a/lib/engine/presence/cluster.h
+++ b/lib/engine/presence/cluster.h
@@ -66,16 +66,16 @@ namespace Ekiga
      * from the Cluster.
      * @param The Heap in question.
      */
-    boost::signal1<void, HeapPtr > heap_added;
-    boost::signal1<void, HeapPtr > heap_removed;
+    boost::signals2::signal<void(HeapPtr)> heap_added;
+    boost::signals2::signal<void(HeapPtr)> heap_removed;
 
     /** Those signals are forwarded from the given Heap
      * @param The Heap in question.
      */
-    boost::signal1<void, HeapPtr > heap_updated;
-    boost::signal2<void, HeapPtr , PresentityPtr > presentity_added;
-    boost::signal2<void, HeapPtr , PresentityPtr > presentity_updated;
-    boost::signal2<void, HeapPtr , PresentityPtr > presentity_removed;
+    boost::signals2::signal<void(HeapPtr)> heap_updated;
+    boost::signals2::signal<void(HeapPtr , PresentityPtr )> presentity_added;
+    boost::signals2::signal<void(HeapPtr , PresentityPtr )> presentity_updated;
+    boost::signals2::signal<void(HeapPtr , PresentityPtr )> presentity_removed;
   };
 
   typedef boost::shared_ptr<Cluster> ClusterPtr;
diff --git a/lib/engine/presence/heap.h b/lib/engine/presence/heap.h
index 859168a..753f16c 100644
--- a/lib/engine/presence/heap.h
+++ b/lib/engine/presence/heap.h
@@ -83,15 +83,15 @@ namespace Ekiga
 
     /** This signal is emitted  when a Presentity has been added to the Heap.
      */
-    boost::signal1<void, PresentityPtr > presentity_added;
+    boost::signals2::signal<void(PresentityPtr)> presentity_added;
 
     /** This signal is emitted when a Presentity has been updated in the Heap.
      */
-    boost::signal1<void, PresentityPtr > presentity_updated;
+    boost::signals2::signal<void(PresentityPtr)> presentity_updated;
 
     /** This signal is emitted when a Presentity has been removed from the Heap.
      */
-    boost::signal1<void, PresentityPtr > presentity_removed;
+    boost::signals2::signal<void(PresentityPtr)> presentity_removed;
   };
 
   typedef boost::shared_ptr<Heap> HeapPtr;
diff --git a/lib/engine/presence/presence-core.h b/lib/engine/presence/presence-core.h
index d7194cb..0055585 100644
--- a/lib/engine/presence/presence-core.h
+++ b/lib/engine/presence/presence-core.h
@@ -94,8 +94,8 @@ namespace Ekiga
      * presence information about an uri it was required to handle.
      * The information is given as a pair of strings (uri, data).
      */
-    boost::signal2<void, std::string, std::string> presence_received;
-    boost::signal2<void, std::string, std::string> status_received;
+    boost::signals2::signal<void(std::string, std::string)> presence_received;
+    boost::signals2::signal<void(std::string, std::string)> status_received;
   };
 
   class PresencePublisher
@@ -173,22 +173,22 @@ namespace Ekiga
     /** This signal is emitted when an Ekiga::Cluster has been added
      * to the PresenceCore Service.
      */
-    boost::signal1<void, ClusterPtr > cluster_added;
+    boost::signals2::signal<void(ClusterPtr)> cluster_added;
 
     /** Those signals are forwarding the heap_added, heap_updated
      * and heap_removed from the given Cluster.
      *
      */
-    boost::signal2<void, ClusterPtr , HeapPtr > heap_added;
-    boost::signal2<void, ClusterPtr , HeapPtr > heap_updated;
-    boost::signal2<void, ClusterPtr , HeapPtr > heap_removed;
+    boost::signals2::signal<void(ClusterPtr , HeapPtr )> heap_added;
+    boost::signals2::signal<void(ClusterPtr , HeapPtr )> heap_updated;
+    boost::signals2::signal<void(ClusterPtr , HeapPtr )> heap_removed;
 
     /** Those signals are forwarding the presentity_added, presentity_updated
      * and presentity_removed from the given Heap of the given Cluster.
      */
-    boost::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_added;
-    boost::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_updated;
-    boost::signal3<void, ClusterPtr , HeapPtr , PresentityPtr > presentity_removed;
+    boost::signals2::signal<void(ClusterPtr , HeapPtr , PresentityPtr )> presentity_added;
+    boost::signals2::signal<void(ClusterPtr , HeapPtr , PresentityPtr )> presentity_updated;
+    boost::signals2::signal<void(ClusterPtr , HeapPtr , PresentityPtr )> presentity_removed;
 
   private:
 
@@ -249,8 +249,8 @@ namespace Ekiga
     /** Those signals are emitted whenever information has been received
      * about an uri ; the information is a pair of strings (uri, information).
      */
-    boost::signal2<void, std::string, std::string> presence_received;
-    boost::signal2<void, std::string, std::string> status_received;
+    boost::signals2::signal<void(std::string, std::string)> presence_received;
+    boost::signals2::signal<void(std::string, std::string)> status_received;
 
   private:
 
diff --git a/lib/engine/presence/uri-presentity.h b/lib/engine/presence/uri-presentity.h
index 9d3f0bb..6434c23 100644
--- a/lib/engine/presence/uri-presentity.h
+++ b/lib/engine/presence/uri-presentity.h
@@ -60,7 +60,7 @@ namespace Ekiga
    */
   class URIPresentity:
     public Ekiga::Presentity,
-    public boost::signals::trackable
+    public boost::signals2::trackable
   {
   public:
 
diff --git a/lib/engine/protocol/call-core.h b/lib/engine/protocol/call-core.h
index bff0d24..cb4a987 100644
--- a/lib/engine/protocol/call-core.h
+++ b/lib/engine/protocol/call-core.h
@@ -46,7 +46,7 @@
 #include "call-protocol-manager.h"
 
 #include <boost/smart_ptr.hpp>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include <set>
@@ -64,7 +64,7 @@ namespace Ekiga
 
   class CallCore:
     public Service,
-    public boost::signals::trackable
+    public boost::signals2::trackable
     {
 
   public:
@@ -123,7 +123,7 @@ namespace Ekiga
       /** This signal is emitted when a Ekiga::CallManager has been
        * added to the CallCore Service.
        */
-      boost::signal1<void, boost::shared_ptr<CallManager> > manager_added;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>)> manager_added;
 
 
       /*** Call Management ***/                 
@@ -138,21 +138,21 @@ namespace Ekiga
       
       /** See call.h for the API
        */
-      boost::signal2<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call> > ringing_call;
-      boost::signal2<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call> > setup_call;
-      boost::signal2<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call> > missed_call;
-      boost::signal3<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call>, std::string> 
cleared_call;
-      boost::signal2<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call> > established_call;
-      boost::signal2<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call> > held_call;
-      boost::signal2<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call> > retrieved_call;
-      boost::signal5<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call>, std::string, 
Call::StreamType, bool> stream_opened;
-      boost::signal5<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call>, std::string, 
Call::StreamType, bool> stream_closed;
-      boost::signal4<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call>, std::string, 
Call::StreamType> stream_paused;
-      boost::signal4<void, boost::shared_ptr<CallManager> , boost::shared_ptr<Call>, std::string, 
Call::StreamType> stream_resumed;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>)> ringing_call;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>)> setup_call;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>)> missed_call;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>, std::string)> 
cleared_call;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>)> 
established_call;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>)> held_call;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>)> retrieved_call;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>, std::string, 
Call::StreamType, bool)> stream_opened;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>, std::string, 
Call::StreamType, bool)> stream_closed;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>, std::string, 
Call::StreamType)> stream_paused;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>, boost::shared_ptr<Call>, std::string, 
Call::StreamType)> stream_resumed;
 
       /*** Misc ***/
-      boost::signal1<void, boost::shared_ptr<CallManager> > manager_ready;
-      boost::signal0<void> ready;
+      boost::signals2::signal<void(boost::shared_ptr<CallManager>)> manager_ready;
+      boost::signals2::signal<void(void)> ready;
 
       /** This chain allows the CallCore to report errors to the user
        */
diff --git a/lib/engine/protocol/call-manager.h b/lib/engine/protocol/call-manager.h
index ec10091..2a0df32 100644
--- a/lib/engine/protocol/call-manager.h
+++ b/lib/engine/protocol/call-manager.h
@@ -40,7 +40,7 @@
 #define __CALL_MANAGER_H__
 
 #include <set>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include <boost/smart_ptr.hpp>
@@ -99,7 +99,7 @@ namespace Ekiga
     /** This signal is emitted when a Ekiga::CallProtocolManager has been
      * added to the CallManager.
      */
-    boost::signal1<void, boost::shared_ptr<CallProtocolManager> > manager_added;
+    boost::signals2::signal<void(boost::shared_ptr<CallProtocolManager>)> manager_added;
 
 
     /*                 
@@ -213,7 +213,7 @@ namespace Ekiga
     /*
      * MISC
      */
-    boost::signal0<void> ready;
+    boost::signals2::signal<void(void)> ready;
 
     private:
     std::set<boost::shared_ptr<CallProtocolManager> > managers;
diff --git a/lib/engine/protocol/call.h b/lib/engine/protocol/call.h
index 74f1742..3ec3b19 100644
--- a/lib/engine/protocol/call.h
+++ b/lib/engine/protocol/call.h
@@ -38,7 +38,7 @@
 #ifndef __CALL_H__
 #define __CALL_H__
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 #include <string>
 
@@ -198,69 +198,69 @@ namespace Ekiga
 
       /* Signal emitted when the call is established
        */
-      boost::signal0<void> established;
+      boost::signals2::signal<void(void)> established;
 
       /* Signal emitted when an established call is cleared
        * @param: a string describing why the call was cleared
        */
-      boost::signal1<void, std::string> cleared;
+      boost::signals2::signal<void(std::string)> cleared;
 
       /* Signal emitted when the call is missed, ie cleared
        * without having been established
        */
-      boost::signal0<void> missed;
+      boost::signals2::signal<void(void)> missed;
 
       /* Signal emitted when the call is forwarded
        */
-      boost::signal0<void> forwarded;
+      boost::signals2::signal<void(void)> forwarded;
 
       /* Signal emitted when the call is held
        */
-      boost::signal0<void> held;
+      boost::signals2::signal<void(void)> held;
 
       /* Signal emitted when the call is retrieved
        */
-      boost::signal0<void> retrieved;
+      boost::signals2::signal<void(void)> retrieved;
 
       /* Signal emitted when the call is being setup
        */
-      boost::signal0<void> setup;
+      boost::signals2::signal<void(void)> setup;
 
       /* Signal emitted when the remote party is ringing
        */
-      boost::signal0<void> ringing;
+      boost::signals2::signal<void(void)> ringing;
 
       /* Signal emitted when a stream is opened
        * @param the stream name
        * @param the stream type
        * @param transmission or reception
        */
-      boost::signal3<void, std::string, StreamType, bool> stream_opened;
+      boost::signals2::signal<void(std::string, StreamType, bool)> stream_opened;
 
       /* Signal emitted when a stream is closed
        * @param the stream name
        * @param the stream type
        * @param transmission or reception
        */
-      boost::signal3<void, std::string, StreamType, bool> stream_closed;
+      boost::signals2::signal<void(std::string, StreamType, bool)> stream_closed;
 
       /* Signal emitted when a transmitted stream is paused
        * @param the stream name
        * @param the stream type
        * @param transmission or reception
        */
-      boost::signal2<void, std::string, StreamType> stream_paused;
+      boost::signals2::signal<void(std::string, StreamType)> stream_paused;
 
       /* Signal emitted when a transmitted stream is resumed
        * @param the stream name
        * @param the stream type
        * @param transmission or reception
        */
-      boost::signal2<void, std::string, StreamType> stream_resumed;
+      boost::signals2::signal<void(std::string, StreamType)> stream_resumed;
 
       /** This signal is emitted when the Call is removed.
        */
-      boost::signal0<void> removed;
+      boost::signals2::signal<void(void)> removed;
      
     };
 
diff --git a/lib/engine/videoinput/videoinput-core.h b/lib/engine/videoinput/videoinput-core.h
index 19a636d..3b7065e 100644
--- a/lib/engine/videoinput/videoinput-core.h
+++ b/lib/engine/videoinput/videoinput-core.h
@@ -45,7 +45,7 @@
 #include "videoinput-manager.h"
 #include "videoinput-gmconf-bridge.h"
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 #include <glib.h>
 #include <set>
@@ -144,7 +144,7 @@ namespace Ekiga
       /** This signal is emitted when a Ekiga::VideoInputManager has been
        * added to the VideoInputCore Service.
        */
-       boost::signal1<void, VideoInputManager &> manager_added;
+       boost::signals2::signal<void(VideoInputManager &)> manager_added;
 
 
       /*** VideoInput Device Management ***/
@@ -275,23 +275,23 @@ namespace Ekiga
 
       /** See videoinput-manager.h for the API
        */
-      boost::signal3<void, VideoInputManager &, VideoInputDevice &, VideoInputSettings&> device_opened;
-      boost::signal2<void, VideoInputManager &, VideoInputDevice &> device_closed;
-      boost::signal3<void, VideoInputManager &, VideoInputDevice &, VideoInputErrorCodes> device_error;
+      boost::signals2::signal<void(VideoInputManager &, VideoInputDevice &, VideoInputSettings&)> 
device_opened;
+      boost::signals2::signal<void(VideoInputManager &, VideoInputDevice &)> device_closed;
+      boost::signals2::signal<void(VideoInputManager &, VideoInputDevice &, VideoInputErrorCodes)> 
device_error;
 
       /** This signal is emitted when a video input has been added to the system.
        * This signal will be emitted if add_device was called with a device name and
        * a manager claimed support for this device.
        * @param device the video input device that was added.
        */
-      boost::signal2<void, VideoInputDevice, bool> device_added;
+      boost::signals2::signal<void(VideoInputDevice, bool)> device_added;
 
       /** This signal is emitted when a video input has been removed from the system.
        * This signal will be emitted if remove_device was called with a device name and
        * a manager claimed support for this device.
        * @param device the video input device that was removed.
        */
-      boost::signal2<void, VideoInputDevice, bool> device_removed;
+      boost::signals2::signal<void(VideoInputDevice, bool)> device_removed;
 
   private:
       void on_set_device (const VideoInputDevice & device);
diff --git a/lib/engine/videoinput/videoinput-manager.h b/lib/engine/videoinput/videoinput-manager.h
index 7235c54..3b09c41 100644
--- a/lib/engine/videoinput/videoinput-manager.h
+++ b/lib/engine/videoinput/videoinput-manager.h
@@ -39,7 +39,7 @@
 #define __VIDEOINPUT_MANAGER_H__
 
 #include <vector>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include "videoinput-info.h"
@@ -159,18 +159,18 @@ namespace Ekiga
        * @param device the video input device that was opened.
        * @param config the current video input device configuration (current brightness, colour, etc.).
        */
-      boost::signal2<void, VideoInputDevice, VideoInputSettings> device_opened;
+      boost::signals2::signal<void(VideoInputDevice, VideoInputSettings)> device_opened;
 
       /** This signal is emitted when a video input device is closed.
        * @param device the video input device that was closed.
        */
-      boost::signal1<void, VideoInputDevice> device_closed;
+      boost::signals2::signal<void(VideoInputDevice)> device_closed;
 
       /** This signal is emitted when an error occurs when opening a video input device.
        * @param device the video input device that caused the error.
        * @param error_code the video input device error code.
        */
-      boost::signal2<void, VideoInputDevice, VideoInputErrorCodes> device_error;
+      boost::signals2::signal<void(VideoInputDevice, VideoInputErrorCodes)> device_error;
 
   protected:  
       typedef struct ManagerState {
diff --git a/lib/engine/videooutput/videooutput-core.h b/lib/engine/videooutput/videooutput-core.h
index 905d915..d1640e2 100644
--- a/lib/engine/videooutput/videooutput-core.h
+++ b/lib/engine/videooutput/videooutput-core.h
@@ -42,7 +42,7 @@
 #include "videooutput-gmconf-bridge.h"
 #include "videooutput-manager.h"
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 #include <set>
 #include <map>
@@ -113,7 +113,7 @@ namespace Ekiga
       /** This signal is emitted when a Ekiga::VideoOutputManager has been
        * added to the VideoOutputCore Service.
        */
-      boost::signal1<void, VideoOutputManager &> manager_added;
+      boost::signals2::signal<void(VideoOutputManager &)> manager_added;
 
 
       /*** Videooutput Management ***/
@@ -163,11 +163,11 @@ namespace Ekiga
 
       /** See videooutput-manager.h for the API
        */
-      boost::signal6<void, VideoOutputManager &, VideoOutputAccel, VideoOutputMode, unsigned, bool, bool> 
device_opened;
-      boost::signal1<void, VideoOutputManager &> device_closed;
-      boost::signal2<void, VideoOutputManager &, VideoOutputErrorCodes> device_error;
-      boost::signal2<void, VideoOutputManager &, VideoOutputFSToggle> fullscreen_mode_changed;
-      boost::signal4<void, VideoOutputManager &, unsigned, unsigned, VideoOutputMode> size_changed;
+      boost::signals2::signal<void(VideoOutputManager &, VideoOutputAccel, VideoOutputMode, unsigned, bool, 
bool)> device_opened;
+      boost::signals2::signal<void(VideoOutputManager &)> device_closed;
+      boost::signals2::signal<void(VideoOutputManager &, VideoOutputErrorCodes)> device_error;
+      boost::signals2::signal<void(VideoOutputManager &, VideoOutputFSToggle)> fullscreen_mode_changed;
+      boost::signals2::signal<void(VideoOutputManager &, unsigned, unsigned, VideoOutputMode)> size_changed;
 
 
   private:
diff --git a/lib/engine/videooutput/videooutput-manager.h b/lib/engine/videooutput/videooutput-manager.h
index 599bfbd..d2c9ca4 100644
--- a/lib/engine/videooutput/videooutput-manager.h
+++ b/lib/engine/videooutput/videooutput-manager.h
@@ -38,7 +38,7 @@
 #ifndef __VIDEOOUTPUT_MANAGER_H__
 #define __VIDEOOUTPUT_MANAGER_H__
 
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 #include <boost/bind.hpp>
 
 #include "videooutput-info.h"
@@ -109,16 +109,16 @@ namespace Ekiga
        * @param both_streams if a frame from both local and remote stream has been received.
        * @param ext_stream if a frame from an extended video stream has been received.
        */
-      boost::signal5<void, VideoOutputAccel, VideoOutputMode, unsigned, bool, bool> device_opened;
+      boost::signals2::signal<void(VideoOutputAccel, VideoOutputMode, unsigned, bool, bool)> device_opened;
 
       /** This signal is emitted when a video output device is closed.
        */
-      boost::signal0<void> device_closed;
+      boost::signals2::signal<void(void)> device_closed;
 
       /** This signal is emitted when an error occurs when opening a video output device.
        * @param error_code the video output device error code.
        */
-      boost::signal1<void, VideoOutputErrorCodes> device_error;
+      boost::signals2::signal<void(VideoOutputErrorCodes)> device_error;
 
       /** This signal is emitted when a manager switches autonomously into or out of fullscreen mode.
        * Some managers like DX and XV  allow the user to switch between FS
@@ -128,7 +128,7 @@ namespace Ekiga
        * or when it is being zoomed in or out.
        * @param toggle VO_FS_ON or VO_FS_OFF depending on whether FS was activated or deactivated.
        */
-      boost::signal1<void, VideoOutputFSToggle> fullscreen_mode_changed;
+      boost::signals2::signal<void(VideoOutputFSToggle)> fullscreen_mode_changed;
 
       /** This signal is emitted the video output size has changed.
        * This signal is called whenever the size of the widget carrying the video signal
@@ -138,7 +138,7 @@ namespace Ekiga
        * @param height the new height of the widget.
        * @param mode the current frame mode.
        */
-      boost::signal3<void, unsigned, unsigned, VideoOutputMode> size_changed;
+      boost::signals2::signal<void(unsigned, unsigned, VideoOutputMode)> size_changed;
 
   protected:
       virtual void get_display_info (DisplayInfo &) { };
diff --git a/plugins/avahi/avahi-cluster.h b/plugins/avahi/avahi-cluster.h
index 602e8d0..1821553 100644
--- a/plugins/avahi/avahi-cluster.h
+++ b/plugins/avahi/avahi-cluster.h
@@ -53,7 +53,7 @@ namespace Avahi
   class Cluster:
     public Ekiga::Service,
     public Ekiga::ClusterImpl<Heap>,
-    public boost::signals::trackable
+    public boost::signals2::trackable
   {
   public:
 
diff --git a/plugins/avahi/avahi-heap.h b/plugins/avahi/avahi-heap.h
index 81e3944..6449c2b 100644
--- a/plugins/avahi/avahi-heap.h
+++ b/plugins/avahi/avahi-heap.h
@@ -60,7 +60,7 @@ namespace Avahi
   class Heap:
     public Ekiga::PresenceFetcher,
     public Ekiga::HeapImpl<Ekiga::URIPresentity>,
-    public boost::signals::trackable
+    public boost::signals2::trackable
   {
   public:
 
diff --git a/plugins/ldap/ldap-book.h b/plugins/ldap/ldap-book.h
index f02ba3b..bcf0519 100644
--- a/plugins/ldap/ldap-book.h
+++ b/plugins/ldap/ldap-book.h
@@ -124,7 +124,7 @@ namespace OPENLDAP
 
     xmlNodePtr get_node ();
 
-    boost::signal0<void> trigger_saving;
+    boost::signals2::signal<void(void)> trigger_saving;
 
     bool is_ekiga_net_book () const;
 
diff --git a/plugins/libnotify/libnotify-main.cpp b/plugins/libnotify/libnotify-main.cpp
index e6b7f9d..33ef931 100644
--- a/plugins/libnotify/libnotify-main.cpp
+++ b/plugins/libnotify/libnotify-main.cpp
@@ -51,7 +51,7 @@
 
 class LibNotify:
   public Ekiga::Service,
-  public boost::signals::trackable
+  public boost::signals2::trackable
 {
 public:
 
@@ -77,7 +77,7 @@ private:
                              boost::shared_ptr<Ekiga::Call>  call);
   void on_call_notification_closed (gpointer self);
 
-  typedef std::map<boost::shared_ptr<Ekiga::Notification>, std::pair<boost::signals::connection, 
boost::shared_ptr<NotifyNotification> > > container_type;
+  typedef std::map<boost::shared_ptr<Ekiga::Notification>, std::pair<boost::signals2::connection, 
boost::shared_ptr<NotifyNotification> > > container_type;
   container_type live;
 };
 
@@ -234,10 +234,10 @@ LibNotify::on_notification_added (boost::shared_ptr<Ekiga::Notification> notific
                                     notify_action_cb, notification.get (), NULL);
 
   g_signal_connect (notif, "closed", G_CALLBACK (on_notif_closed), notification.get ());
-  boost::signals::connection conn = notification->removed.connect (boost::bind 
(&LibNotify::on_notification_removed,
+  boost::signals2::connection conn = notification->removed.connect (boost::bind 
(&LibNotify::on_notification_removed,
                                                                                 this, notification));
 
-  live[notification] = std::pair<boost::signals::connection, boost::shared_ptr<NotifyNotification> > (conn, 
boost::shared_ptr<NotifyNotification> (notif, g_object_unref));
+  live[notification] = std::pair<boost::signals2::connection, boost::shared_ptr<NotifyNotification> > (conn, 
boost::shared_ptr<NotifyNotification> (notif, g_object_unref));
 
   notify_notification_show (notif, NULL);
 }
diff --git a/plugins/loudmouth/loudmouth-account.h b/plugins/loudmouth/loudmouth-account.h
index c7a86b2..0e7e595 100644
--- a/plugins/loudmouth/loudmouth-account.h
+++ b/plugins/loudmouth/loudmouth-account.h
@@ -70,7 +70,7 @@ namespace LM
 
     xmlNodePtr get_node () const;
 
-    boost::signal0<void> trigger_saving;
+    boost::signals2::signal<void(void)> trigger_saving;
 
     const std::string get_name () const;
 
diff --git a/plugins/loudmouth/loudmouth-heap-roster.h b/plugins/loudmouth/loudmouth-heap-roster.h
index f2ad46b..1fee4f5 100644
--- a/plugins/loudmouth/loudmouth-heap-roster.h
+++ b/plugins/loudmouth/loudmouth-heap-roster.h
@@ -46,7 +46,7 @@ namespace LM
   class HeapRoster:
     public Ekiga::HeapImpl<Presentity>,
     public LM::Handler,
-    public boost::signals::trackable
+    public boost::signals2::trackable
   {
   public:
 
diff --git a/plugins/loudmouth/loudmouth-helpers.h b/plugins/loudmouth/loudmouth-helpers.h
index dff9cda..4860561 100644
--- a/plugins/loudmouth/loudmouth-helpers.h
+++ b/plugins/loudmouth/loudmouth-helpers.h
@@ -37,7 +37,7 @@
 #define __LOUDMOUTH_HELPERS_H__
 
 #include <boost/smart_ptr.hpp>
-#include <boost/signals.hpp>
+#include <boost/signals2.hpp>
 
 #include <loudmouth/loudmouth.h>
 
diff --git a/plugins/loudmouth/loudmouth-presentity.h b/plugins/loudmouth/loudmouth-presentity.h
index d8d5222..63f9d47 100644
--- a/plugins/loudmouth/loudmouth-presentity.h
+++ b/plugins/loudmouth/loudmouth-presentity.h
@@ -78,7 +78,7 @@ namespace LM
 
     bool has_chat;
 
-    boost::signal0<void> chat_requested;
+    boost::signals2::signal<void(void)> chat_requested;
 
   private:
     LmConnection* connection;
diff --git a/plugins/resource-list/rl-heap.cpp b/plugins/resource-list/rl-heap.cpp
index beeac6b..1d38776 100644
--- a/plugins/resource-list/rl-heap.cpp
+++ b/plugins/resource-list/rl-heap.cpp
@@ -185,7 +185,7 @@ RL::Heap::visit_presentities (boost::function1<bool, Ekiga::PresentityPtr > visi
 {
   bool go_on = true;
 
-  for (std::map<PresentityPtr,std::list<boost::signals::connection> >::const_iterator
+  for (std::map<PresentityPtr,std::list<boost::signals2::connection> >::const_iterator
         iter = presentities.begin ();
        go_on && iter != presentities.end ();
        ++iter)
@@ -254,7 +254,7 @@ RL::Heap::refresh ()
   while ( !presentities.empty ()) {
 
     presentities.begin()->first->removed ();
-    for (std::list<boost::signals::connection>::const_iterator iter2
+    for (std::list<boost::signals2::connection>::const_iterator iter2
           = presentities.begin()->second.begin ();
         iter2 != presentities.begin()->second.end ();
         ++iter2)
@@ -366,7 +366,7 @@ RL::Heap::parse_list (xmlNodePtr list)
        && xmlStrEqual (BAD_CAST ("entry"), child->name)) {
 
       PresentityPtr presentity(new Presentity (services, path, doc, child, writable));
-      std::list<boost::signals::connection> conns;
+      std::list<boost::signals2::connection> conns;
       conns.push_back (presentity->updated.connect (boost::bind (boost::ref (presentity_updated), 
presentity)));
       conns.push_back (presentity->removed.connect (boost::bind(boost::ref 
(presentity_removed),presentity)));
       conns.push_back (presentity->trigger_reload.connect (boost::bind (&RL::Heap::refresh, this)));
@@ -381,7 +381,7 @@ void
 RL::Heap::push_presence (const std::string uri_,
                         const std::string presence)
 {
-  for (std::map<PresentityPtr,std::list<boost::signals::connection> >::const_iterator
+  for (std::map<PresentityPtr,std::list<boost::signals2::connection> >::const_iterator
         iter = presentities.begin ();
        iter != presentities.end ();
        ++iter) {
@@ -395,7 +395,7 @@ void
 RL::Heap::push_status (const std::string uri_,
                       const std::string status)
 {
-  for (std::map<PresentityPtr,std::list<boost::signals::connection> >::const_iterator
+  for (std::map<PresentityPtr,std::list<boost::signals2::connection> >::const_iterator
         iter = presentities.begin ();
        iter != presentities.end ();
        ++iter) {
@@ -514,7 +514,7 @@ RL::Heap::new_entry ()
                           "contact on a remote server"));
 
   std::set<std::string> all_groups;
-  for (std::map<PresentityPtr,std::list<boost::signals::connection> >::const_iterator
+  for (std::map<PresentityPtr,std::list<boost::signals2::connection> >::const_iterator
         iter = presentities.begin ();
        iter != presentities.end ();
        ++iter) {
diff --git a/plugins/resource-list/rl-heap.h b/plugins/resource-list/rl-heap.h
index 67f38bd..de3b41d 100644
--- a/plugins/resource-list/rl-heap.h
+++ b/plugins/resource-list/rl-heap.h
@@ -90,7 +90,7 @@ namespace RL {
     void push_status (const std::string uri,
                      const std::string status);
 
-    boost::signal0<void> trigger_saving;
+    boost::signals2::signal<void(void)> trigger_saving;
 
   private:
 
@@ -106,7 +106,7 @@ namespace RL {
     boost::shared_ptr<xmlDoc> doc;
     xmlNodePtr list_node;
 
-    std::map<PresentityPtr, std::list<boost::signals::connection> > presentities;
+    std::map<PresentityPtr, std::list<boost::signals2::connection> > presentities;
 
     void refresh ();
 
diff --git a/plugins/resource-list/rl-list.cpp b/plugins/resource-list/rl-list.cpp
index 1049a46..45fc9ac 100644
--- a/plugins/resource-list/rl-list.cpp
+++ b/plugins/resource-list/rl-list.cpp
@@ -94,9 +94,9 @@ public: // no need to make anything private
 
   void publish () const;
 
-  boost::signal1<void, boost::shared_ptr<Entry> > entry_added;
-  boost::signal1<void, boost::shared_ptr<Entry> > entry_updated;
-  boost::signal1<void, boost::shared_ptr<Entry> > entry_removed;
+  boost::signals2::signal<void(boost::shared_ptr<Entry>)> entry_added;
+  boost::signals2::signal<void(boost::shared_ptr<Entry>)> entry_updated;
+  boost::signals2::signal<void(boost::shared_ptr<Entry>)> entry_removed;
 
 
   /* data for its children */
@@ -104,7 +104,7 @@ public: // no need to make anything private
 
   std::list<ChildType> ordering;
   std::list<boost::shared_ptr<List> > lists;
-  std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals::connection> > > entries;
+  std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals2::connection> > > entries;
 };
 
 
@@ -235,12 +235,12 @@ RL::ListImpl::flush ()
     (*iter)->flush ();
   lists.clear ();
 
-  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals::connection> > >::iterator 
iter = entries.begin ();
+  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals2::connection> > >::iterator 
iter = entries.begin ();
        iter != entries.end ();
        ++iter) {
 
     iter->first->removed ();
-    for (std::list<boost::signals::connection>::iterator conn_iter
+    for (std::list<boost::signals2::connection>::iterator conn_iter
           = iter->second.begin ();
         conn_iter != iter->second.end ();
         ++conn_iter)
@@ -342,10 +342,10 @@ RL::ListImpl::parse ()
                                                            entry_pos,
                                                            display_name,
                                                            doc, child));
-      std::list<boost::signals::connection> conns;
+      std::list<boost::signals2::connection> conns;
       conns.push_back (entry->updated.connect (boost::bind (boost::ref (entry_updated), entry)));
       conns.push_back (entry->removed.connect (boost::bind (boost::ref (entry_removed), entry)));
-      entries.push_back (std::pair<boost::shared_ptr<Entry>, std::list<boost::signals::connection> > (entry, 
conns));
+      entries.push_back (std::pair<boost::shared_ptr<Entry>, std::list<boost::signals2::connection> > 
(entry, conns));
       ordering.push_back (ENTRY);
       entry_pos++;
       entry_added (entry);
@@ -363,7 +363,7 @@ RL::ListImpl::push_presence (const std::string uri_,
        ++iter)
     (*iter)->push_presence (uri_, presence);
 
-  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals::connection> > 
::const_iterator iter = entries.begin ();
+  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals2::connection> > 
::const_iterator iter = entries.begin ();
        iter != entries.end ();
        ++iter) {
 
@@ -381,7 +381,7 @@ RL::ListImpl::push_status (const std::string uri_,
        ++iter)
     (*iter)->push_status (uri_, status);
 
-  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals::connection> > 
::const_iterator iter = entries.begin ();
+  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals2::connection> > 
::const_iterator iter = entries.begin ();
        iter != entries.end ();
        ++iter) {
 
@@ -400,7 +400,7 @@ RL::ListImpl::visit_presentities (boost::function1<bool, Ekiga::Presentity&> vis
        ++iter)
     go_on = (*iter)->visit_presentities (visitor);
 
-  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals::connection> > 
::const_iterator iter = entries.begin ();
+  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals2::connection> > 
::const_iterator iter = entries.begin ();
        go_on && iter != entries.end ();
        ++iter) {
 
@@ -418,7 +418,7 @@ RL::ListImpl::publish () const
        ++iter)
     (*iter)->publish ();
 
-  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals::connection> > 
::const_iterator iter = entries.begin ();
+  for (std::list<std::pair<boost::shared_ptr<Entry>, std::list<boost::signals2::connection> > 
::const_iterator iter = entries.begin ();
        iter != entries.end ();
        ++iter) {
 
diff --git a/plugins/resource-list/rl-list.h b/plugins/resource-list/rl-list.h
index 77a64d4..ca5c02b 100644
--- a/plugins/resource-list/rl-list.h
+++ b/plugins/resource-list/rl-list.h
@@ -74,9 +74,9 @@ namespace RL
 
     void publish () const;
 
-    boost::signal1<void, boost::shared_ptr<Entry> > entry_added;
-    boost::signal1<void, boost::shared_ptr<Entry> > entry_updated;
-    boost::signal1<void, boost::shared_ptr<Entry> > entry_removed;
+    boost::signals2::signal<void(boost::shared_ptr<Entry>)> entry_added;
+    boost::signals2::signal<void(boost::shared_ptr<Entry>)> entry_updated;
+    boost::signals2::signal<void(boost::shared_ptr<Entry>)> entry_removed;
 
     /* this method orders the list to get rid of all its children */
     void flush ();
diff --git a/plugins/resource-list/rl-presentity.h b/plugins/resource-list/rl-presentity.h
index fbd998a..53bfd10 100644
--- a/plugins/resource-list/rl-presentity.h
+++ b/plugins/resource-list/rl-presentity.h
@@ -79,7 +79,7 @@ namespace RL
 
     bool populate_menu (Ekiga::MenuBuilder &);
 
-    boost::signal0<void> trigger_reload;
+    boost::signals2::signal<void(void)> trigger_reload;
 
   private:
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/lib/engine/framework/scoped-connections.h b/lib/engine/framework/scoped-connections.h
index 234cabf..cddf557 100644
--- a/lib/engine/framework/scoped-connections.h
+++ b/lib/engine/framework/scoped-connections.h
@@ -42,9 +42,9 @@
 
 /* The boost signals library has several tricks to disconnect connections on signals
  * automatically, namely :
  * - inherit from boost::signals::trackable, which is good to get rid of
  * connnections to a dying object ;
  * - use a boost::signals::scoped_connection which makes it possible to do things
  * more manually, but is annoying when you need many of them because they're not
  * easy to put in a container ;
  *
@@ -65,12 +65,12 @@ namespace Ekiga {
     ~scoped_connections ()
       { clear (); }
 
-    void add (boost::signals::connection conn)
+    void add (boost::signals2::connection conn)
     { conns.push_front (conn); }
 
     void clear ()
     {
-      for (std::list<boost::signals::connection>::iterator iter = conns.begin ();
+      for (std::list<boost::signals2::connection>::iterator iter = conns.begin ();
           iter != conns.end ();
           ++iter)
        iter->disconnect ();
@@ -79,7 +79,7 @@ namespace Ekiga {
 
   private:
 
-    std::list<boost::signals::connection> conns;
+    std::list<boost::signals2::connection> conns;
   };
 };
 
@@ -42,9 +42,9 @@
 /* The boost signals library has several tricks to disconnect connections on signals
  * automatically, namely :
- * - inherit from boost::signals::trackable, which is good to get rid of
+ * - inherit from boost::signals2::trackable, which is good to get rid of
  * connnections to a dying object ;
@@ -42,9 +42,9 @@
  * connnections to a dying object ;
- * - use a boost::signals::scoped_connection which makes it possible to do things
+ * - use a boost::signals2::scoped_connection which makes it possible to do things
  * more manually, but is annoying when you need many of them because they're not
  * easy to put in a container ;